boto: A Python interface to Amazon Web Services — boto v2.25.0

### Navigation

- index
- modules |
- next |
- boto v2.25.0 »

# boto: A Python interface to Amazon Web Services

An integrated interface to current and future infrastructural services offered by Amazon Web Services.

## Getting Started

If you’ve never used `boto` before, you should read the Getting Started with Boto guide to get familiar with `boto` & its usage.

## Currently Supported Services

- Compute
  - Elastic Compute Cloud (EC2) – (API Reference)
  - Elastic MapReduce (EMR) – (API Reference)
  - Auto Scaling – (API Reference)
  - Kinesis – (API Reference)
- Content Delivery
  - CloudFront – (API Reference)
- Database
  - DynamoDB2 – (API Reference) – (Migration Guide from v1)
  - DynamoDB – (API Reference)
  - Relational Data Services 2 (RDS) – (API Reference) – (Migration Guide from v1)
  - Relational Data Services (RDS) – (API Reference)
  - ElastiCache – (API Reference)
  - Redshift – (API Reference)
  - SimpleDB – (API Reference)
- Deployment and Management
  - CloudFormation – (API Reference)
  - Elastic Beanstalk – (API Reference)
  - Data Pipeline – (API Reference)
  - Opsworks – (API Reference)
  - CloudTrail – (API Reference)
- Identity & Access
  - Identity and Access Management (IAM) – (API Reference)
  - Security Token Service (STS) – (API Reference)
- Application Services
  - Cloudsearch – (API Reference)
  - Elastic Transcoder – (API Reference)
  - Simple Workflow Service (SWF) – (API Reference)
  - Simple Queue Service (SQS) – (API Reference)
  - Simple Notification Service (SNS) – (API Reference)
  - Simple Email Service (SES) – (API Reference)
- Monitoring
  - CloudWatch – (API Reference)
- Networking
  - Route 53 – (API Reference)
  - Virtual Private Cloud (VPC) – (API Reference)
  - Elastic Load Balancing (ELB) – (API Reference)
- Payments & Billing
  - Flexible Payments Service (FPS) – (API Reference)
- Storage
  - Simple Storage Service (S3) – (API Reference)
  - Amazon Glacier – (API Reference)
  - Google Cloud Storage – (API Reference)
- Workforce
  - Mechanical Turk – (API Reference)
- Other
  - Marketplace Web Services – (API Reference)
  - Support – (API Reference)

## Additional Resources

- Applications Built On Boto
- Command Line Utilities
- Boto Config Tutorial
- Contributing to Boto
- Boto Source Repository
- Boto Issue Tracker
- Boto Twitter
- Follow Mitch on Twitter
- Join our IRC channel (#boto on FreeNode).

## Release Notes

- boto v2.25.0
- boto v2.24.0
- boto v2.23.0
- boto v2.22.1
- boto v2.22.0
- boto v2.21.2
- boto v2.21.1
- boto v2.21.0
- boto v2.20.1
- boto v2.20.0
- boto v2.19.0
- boto v2.18.0
- boto v2.17.0
- boto v2.16.0
- boto v2.15.0
- boto v2.14.0
- boto v2.13.3
- boto v2.13.2
- boto v2.13.0
- boto v2.12.0
- boto v2.11.0
- boto v2.10.0
- boto v2.9.9
- boto v2.9.8
- boto v2.9.7
- boto v2.9.6
- boto v2.9.5
- boto v2.9.4
- boto v2.9.3
- boto v2.9.2
- boto v2.9.1
- boto v2.9.0
- boto v2.8.0
- boto v2.7.0
- boto v2.6.0
- boto v2.5.2
- boto v2.5.1
- boto v2.5.0
- boto v2.4.0
- boto v2.3.0
- boto v2.2.2
- boto v2.2.1
- boto v2.2.0
- boto v2.1.1
- boto v2.1.0
- Release Notes for boto 2.0
- Major changes for release 2.0b1

### Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- boto v2.25.0 »